==> eiffelstudio-18.07.10.1981.tar: F_code/C1/in16.c <==
/*
 * Code for class INI_SCANNER_STATE_POOL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in16.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INI_SCANNER_STATE_POOL}.make */
void F20_170 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 19, Current, 1, 0, 195);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {833,1281,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F825_6675(RTCW(tr1), ((EIF_INTEGER_32) 3L));
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F293_3512(RTCW(loc1));
	RTHOOK(3);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {INI_SCANNER_STATE_POOL}.state */
EIF_REFERENCE F20_171 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,Result);
	RTLIU(5);
	
	RTEAA("state", 19, Current, 1, 1, 196);
	RTGC;
	RTHOOK(1);
	loc1 = (EIF_REFERENCE) eif_builtin_ANY_generating_type (arg1);
	loc1 = F1072_8800(RTCW(loc1));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F825_6679(RTCW(tr1), loc1);
	RTHOOK(3);
	if ((EIF_BOOLEAN)(Result == NULL)) {
		RTHOOK(4);
		tr1 = RTLNTY2(eif_new_type(1285, 0x00), 0x00);
		if (RTEQ(arg1, tr1)) {
			RTHOOK(5);
			tr1 = RTLNS(eif_new_type(1285, 0x00).id, 1285, _OBJSIZ_2_0_0_0_0_0_0_0_);
			Result = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(6);
			tr1 = RTLNTY2(eif_new_type(1283, 0x00), 0x00);
			if (RTEQ(arg1, tr1)) {
				RTHOOK(7);
				tr1 = RTLNS(eif_new_type(1283, 0x00).id, 1283, _OBJSIZ_2_0_0_0_0_0_0_0_);
				Result = (EIF_REFERENCE) tr1;
			} else {
				RTHOOK(8);
				tr1 = RTLNTY2(eif_new_type(1284, 0x00), 0x00);
				if (RTEQ(arg1, tr1)) {
					RTHOOK(9);
					tr1 = RTLNS(eif_new_type(1284, 0x00).id, 1284, _OBJSIZ_2_0_0_0_0_0_0_0_);
					Result = (EIF_REFERENCE) tr1;
				} else {
					RTHOOK(10);
					tr1 = RTLNTY2(eif_new_type(1282, 0x00), 0x00);
					if (RTEQ(arg1, tr1)) {
						RTHOOK(11);
						tr1 = RTLNS(eif_new_type(1282, 0x00).id, 1282, _OBJSIZ_2_0_0_0_0_0_0_0_);
						Result = (EIF_REFERENCE) tr1;
					} else {
						RTHOOK(12);
						RTCT0("valid_type_from_precondition", EX_CHECK);
							RTCF0;
					}
				}
			}
		}
		RTHOOK(13);
		tr1 = *(EIF_REFERENCE *)(Current);
		F825_6722(RTCW(tr1), Result, loc1);
	}
	RTHOOK(14);
	RTLE;
	RTEE;
	return Result;
}

/* {INI_SCANNER_STATE_POOL}.state_pool */
EIF_REFERENCE F20_172 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit16 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C1/in16.c <==
/*
 * Code for class INI_SCANNER_STATE_POOL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in16.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INI_SCANNER_STATE_POOL}.make */
void F20_170 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("make", 19, Current, 1, 0, 195);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,832,0xFF01,1287,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F824_6472(RTCW(tr1), ((EIF_INTEGER_32) 3L));
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F598_5921(RTCW(loc1));
	RTHOOK(3);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {INI_SCANNER_STATE_POOL}.state */
EIF_REFERENCE F20_171 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,Result);
	RTLIU(5);
	
	RTEAA("state", 19, Current, 1, 1, 196);
	RTGC;
	RTHOOK(1);
	loc1 = F1_5(arg1);
	loc1 = F1077_8876(RTCW(loc1));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F824_6477(RTCW(tr1), loc1);
	RTHOOK(3);
	if ((EIF_BOOLEAN)(Result == NULL)) {
		RTHOOK(4);
		tr1 = RTLNTY2(eif_new_type(1291, 0x01), 0x01);
		if (RTEQ(arg1, tr1)) {
			RTHOOK(5);
			tr1 = RTLNS(eif_new_type(1291, 0x01).id, 1291, _OBJSIZ_2_0_0_0_0_0_0_0_);
			Result = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(6);
			tr1 = RTLNTY2(eif_new_type(1289, 0x01), 0x01);
			if (RTEQ(arg1, tr1)) {
				RTHOOK(7);
				tr1 = RTLNS(eif_new_type(1289, 0x01).id, 1289, _OBJSIZ_2_0_0_0_0_0_0_0_);
				Result = (EIF_REFERENCE) tr1;
			} else {
				RTHOOK(8);
				tr1 = RTLNTY2(eif_new_type(1290, 0x01), 0x01);
				if (RTEQ(arg1, tr1)) {
					RTHOOK(9);
					tr1 = RTLNS(eif_new_type(1290, 0x01).id, 1290, _OBJSIZ_2_0_0_0_0_0_0_0_);
					Result = (EIF_REFERENCE) tr1;
				} else {
					RTHOOK(10);
					tr1 = RTLNTY2(eif_new_type(1288, 0x01), 0x01);
					if (RTEQ(arg1, tr1)) {
						RTHOOK(11);
						tr1 = RTLNS(eif_new_type(1288, 0x01).id, 1288, _OBJSIZ_2_0_0_0_0_0_0_0_);
						Result = (EIF_REFERENCE) tr1;
					} else {
						RTHOOK(12);
						RTCT0("valid_type_from_precondition", EX_CHECK);
							RTCF0;
					}
				}
			}
		}
		RTHOOK(13);
		tr1 = *(EIF_REFERENCE *)(Current);
		F824_6520(RTCW(tr1), Result, loc1);
	}
	RTHOOK(16);
	RTLE;
	RTEE;
	return Result;
}

/* {INI_SCANNER_STATE_POOL}.state_pool */
EIF_REFERENCE F20_172 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit16 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
